@@ -36,6 +36,7 @@ class CasesClient(object):
         self, name, subject=None, assignee=None, description=None, findings=None
     ):
         """Creates a new case.
+        `Rest documentation <https://developer.code42.com/api/#operation/createCaseUsingPOST>`__
 
         Args:
             name (str): Name of the case.
@@ -55,18 +56,6 @@ class CasesClient(object):
             findings=findings,
         )
 
-    @staticmethod
-    def _make_range(begin_time, end_time):
-        if not begin_time and not end_time:
-            return None
-        if not begin_time:
-            begin_time = datetime.utcfromtimestamp(0)
-        if not end_time:
-            end_time = datetime.utcnow()
-        end = parse_timestamp_to_milliseconds_precision(end_time)
-        start = parse_timestamp_to_milliseconds_precision(begin_time)
-        return "{}/{}".format(start, end)
-
     def get_page(
         self,
         page_num,
@@ -84,6 +73,7 @@ class CasesClient(object):
         **kwargs
     ):
         """Gets individual page of cases.
+        `Rest documentation <https://developer.code42.com/api/#operation/getCasesUsingGET>`__
 
         Args:
             page_num (int): The page number to request.
@@ -109,8 +99,8 @@ class CasesClient(object):
             :class:`py42.response.Py42Response`
         """
 
-        created_at = CasesClient._make_range(min_create_time, max_create_time)
-        updated_at = CasesClient._make_range(min_update_time, max_update_time)
+        created_at = _make_range(min_create_time, max_create_time)
+        updated_at = _make_range(min_update_time, max_update_time)
 
         return self._cases_service.get_page(
             page_num,
@@ -142,6 +132,7 @@ class CasesClient(object):
         **kwargs
     ):
         """Gets all cases.
+        `Rest documentation <https://developer.code42.com/api/#operation/getCasesUsingGET>`__
 
         Args:
             name (str, optional): Filter results by case name, matches partial names. Defaults to None.
@@ -167,8 +158,8 @@ class CasesClient(object):
             that each contain a page of cases.
         """
 
-        created_at = CasesClient._make_range(min_create_time, max_create_time)
-        updated_at = CasesClient._make_range(min_update_time, max_update_time)
+        created_at = _make_range(min_create_time, max_create_time)
+        updated_at = _make_range(min_update_time, max_update_time)
 
         return self._cases_service.get_all(
             name=name,
@@ -185,6 +176,7 @@ class CasesClient(object):
 
     def get(self, case_number):
         """Retrieve case details by case number.
+        `Rest documentation <https://developer.code42.com/api/#operation/getCaseUsingGET>`__
 
         Args:
             case_number (int): Case number of the case.
@@ -196,6 +188,8 @@ class CasesClient(object):
 
     def export_summary(self, case_number):
         """Provides case summary to download as a PDF file.
+        `Rest documentation <https://developer.code42.com/api/#operation/pdfExportUsingGET>`__
+
 
         Args:
             case_number (int): Case number of the case.
@@ -216,6 +210,8 @@ class CasesClient(object):
         status=None,
     ):
         """Updates case details for the given case number.
+        `Rest documentation <https://developer.code42.com/api/#operation/updateCaseUsingPUT>`__
+
 
         Args:
             case_number (int): Case number of the case.
@@ -239,3 +235,15 @@ class CasesClient(object):
             findings=findings,
             status=status,
         )
+
+
+def _make_range(begin_time, end_time):
+    if not begin_time and not end_time:
+        return None
+    if not begin_time:
+        begin_time = datetime.utcfromtimestamp(0)
+    if not end_time:
+        end_time = datetime.utcnow()
+    end = parse_timestamp_to_milliseconds_precision(end_time)
+    start = parse_timestamp_to_milliseconds_precision(begin_time)
+    return "{}/{}".format(start, end)
