@@ -1,3 +1,4 @@
+import re
 from threading import Lock
 
 from py42.exceptions import Py42ChecksumNotFoundError
@@ -195,14 +196,13 @@ class SecurityDataClient(object):
             page_token (str, optional): A token used to indicate the starting point for
                 additional page results. For the first page, do not pass ``page_token``. For
                 all consecutive pages, pass the token from the previous response from
-                field ``nextPgToken``. When using ``page_token``, any sorting parameters from
-                the `FileEventQuery` will be ignored. Defaults to empty string.
+                field ``nextPgToken``. Defaults to empty string.
 
         Returns:
             :class:`py42.response.Py42Response`: A response containing page of events.
         """
 
-        query.page_token = page_token
+        query.page_token = _escape_quote_chars_in_token(page_token)
         response = self._file_event_service.search(query)
         return response
 
@@ -468,3 +468,18 @@ class PlanStorageInfo(object):
     def node_guid(self):
         """The GUID of the storage node containing the archive."""
         return self._node_guid
+
+
+def _escape_quote_chars_in_token(token):
+    """
+    The `nextPgToken` returned in Forensic Search requests with > 10k results is the eventId
+    of the last event returned in the response. Some eventIds have double-quote chars in
+    them, which need to be escaped when passing the token in the next search request.
+    """
+    unescaped_quote_pattern = r'[^\\]"'
+
+    return re.sub(
+        pattern=unescaped_quote_pattern,
+        repl=lambda match: match.group().replace(u'"', r"\""),
+        string=token,
+    )
