@@ -1,7 +1,7 @@
 from py42 import settings
 from py42.services import BaseService
 from py42.services.util import get_all_pages
-from py42.util import parse_timestamp_to_milliseconds_precision
+from py42.util import parse_timestamp_to_microseconds_precision
 from py42.util import to_list
 
 _FILTER_PARAMS = (
@@ -38,11 +38,11 @@ class AuditLogsService(BaseService):
     ):
         date_range = {}
         if begin_time:
-            date_range[u"startTime"] = parse_timestamp_to_milliseconds_precision(
+            date_range[u"startTime"] = parse_timestamp_to_microseconds_precision(
                 begin_time
             )
         if end_time:
-            date_range[u"endTime"] = parse_timestamp_to_milliseconds_precision(end_time)
+            date_range[u"endTime"] = parse_timestamp_to_microseconds_precision(end_time)
 
         uri = u"/rpc/search/search-audit-log"
         page_size = page_size or settings.items_per_page
